PairingOptions

Struct PairingOptions 

pub struct PairingOptions {
    pub le_security_level: Option<PairingSecurityLevel>,
    pub bondable_mode: Option<BondableMode>,
    pub transport: Option<TechnologyType>,
    /* private fields */
}
Parameters that give a caller more fine-grained control over the pairing process. All of the fields of this table are optional and pairing can still succeed if none of them are set.

Fields

le_security_level: Option<PairingSecurityLevel>

Only relevant for LE. If present, determines the Security Manager security level to pair with. If not present, interpreted as PairingSecurityLevel.AUTHENTICATED.

bondable_mode: Option<BondableMode>

If transport is LOW_ENERGY or DUAL_MODE, whether the device should form a bond or not during pairing. If not present, interpreted as bondable mode.

If transport is CLASSIC, this option must be absent or otherwise the value BONDABLE. NON_BONDABLE mode is not currently supported for the CLASSIC transport

transport: Option<TechnologyType>

If transport is LOW_ENERGY, indicate a desire to pair over the LE transport. If transport is CLASSIC, indicate a desire to pair over the Br/Edr transport. If transport is DUAL_MODE, indicate a desire to pair over both transports. If not present, interpreted as TechnologyType.DUAL_MODE